@@ -5,6 +5,11 @@
 #' passed my the user. If a new name for an existing repository is
 #' passed by the user, the name will be updated in the JSON file.
 #'
+#' A note for users outside of the USA.
+#' If the country in `.$cran_mirror$country` has not been previously recorded
+#' in the JSON preferences file (typically, auto set by RStudio),
+#' the `use_rstudio_secondary_repo()` function will set `"country" = "us"`.
+#'
 #' @param ... series of secondary repositories
 #' `ropensci = "https://ropensci.r-universe.dev"`
 #' @inheritParams use_rstudio_prefs
@@ -54,12 +59,16 @@ use_rstudio_secondary_repo <- function(..., .write_json = TRUE, .backup = TRUE)
   current_repos <-
     repo_string_as_named_list(list_current_prefs$cran_mirror$secondary)
 
-  # if one of the new repos has the same value but new name as a previous
-  # then add a new NULL value to the updates list
   user_passed_updated_repos <-
-    current_repos[unlist(current_repos) %in% unlist(user_passed_updated_repos)] %>%
-    purrr::map(~NULL) %>%
-    purrr::update_list(!!!user_passed_updated_repos)
+    # if one of the new repos has the same value but new name as a previous
+    # then add a new NULL value to the updates list
+    purrr::map(current_repos[unlist(current_repos) %in% unlist(user_passed_updated_repos)], ~NULL) %>%
+    # set any existing named repos with same name as passed list to NULL
+    purrr::list_modify(
+      !!!purrr::map(current_repos[names(current_repos) %in% names(user_passed_updated_repos)], ~NULL)
+    ) %>%
+    # add user-defined repos to the list
+    purrr::update_list(!!!purrr::compact(user_passed_updated_repos))
 
   # print updates that will be made --------------------------------------------
   pretty_print_updates(current_repos, user_passed_updated_repos)
